@@ -11,7 +11,7 @@ normalizeUrl('http://sindresorhus.com:80/', {forceHttps: true});
 normalizeUrl('user:password@sindresorhus.com', {stripAuthentication: false});
 normalizeUrl('sindresorhus.com/about.html#contact', {stripHash: true});
 normalizeUrl('https://sindresorhus.com', {stripProtocol: true});
-normalizeUrl('http://www.sindresorhus.com', {stripWWW: false});
+normalizeUrl('http://www.sindresorhus.com', {stripWWW: false}); // eslint-disable-line @typescript-eslint/naming-convention
 normalizeUrl('www.sindresorhus.com?foo=bar&ref=test_ref', {
 	removeQueryParameters: ['ref', /test/],
 });
@@ -21,6 +21,9 @@ normalizeUrl('www.sindresorhus.com?foo=bar', {
 normalizeUrl('www.sindresorhus.com?foo=bar&utm_medium=test&ref=test_ref', {
 	removeQueryParameters: false,
 });
+normalizeUrl('www.sindresorhus.com?foo=bar&ref=test_ref', {
+	keepQueryParameters: ['ref', /test/],
+});
 normalizeUrl('http://sindresorhus.com/', {removeTrailingSlash: false});
 normalizeUrl('http://sindresorhus.com/', {removeSingleSlash: false});
 normalizeUrl('www.sindresorhus.com/foo/default.php', {
